tlsR: Detection and Spatial Analysis of Tertiary Lymphoid Structures
Source:R/tlsR-package.R
tlsR-package.RdFast, reproducible detection and quantitative analysis of tertiary lymphoid structures (TLS) in multiplexed tissue imaging data.
Typical workflow
Load or prepare a named list of data frames (
ldata), one per tissue sample. Each data frame must contain columnsx,y(spatial coordinates in microns), andphenotype(character:"B cell"/"T cell"/ other).Run
detect_TLSto label B+T co-localised regions.(Optional) Run
scan_clusteringto identify windows of significant immune clustering via local Ripley's L.Run
calc_icatto score the internal linearity/organisation of each detected TLS.Run
detect_ticto identify T-cell clusters outside TLS.Use
summarize_TLSto obtain a tidy summary table.Use
plot_TLSto produce publication-ready spatial plots.
References
Amiryousefi et al. (2025) doi:10.1101/2025.09.21.677465
Author
Maintainer: Ali Amiryousefi ali_amiryousefi@hms.harvard.edu (ORCID)
Authors:
Jeremiah Wala jeremiah_wala@dfci.harvard.edu (ORCID)
Other contributors:
Peter Sorger (ORCID) [contributor]